import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpPackerImageIterationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The slug of the HCP Packer Registry image bucket to pull from.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration#bucket_name DataHcpPackerImageIteration#bucket_name}
    */
    readonly bucketName: string;
    /**
    * The channel that points to the version of the image you want.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration#channel DataHcpPackerImageIteration#channel}
    */
    readonly channel: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration#id DataHcpPackerImageIteration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration#timeouts DataHcpPackerImageIteration#timeouts}
    */
    readonly timeouts?: DataHcpPackerImageIterationTimeouts;
}
export interface DataHcpPackerImageIterationBuildsImages {
}
export declare function dataHcpPackerImageIterationBuildsImagesToTerraform(struct?: DataHcpPackerImageIterationBuildsImages): any;
export declare class DataHcpPackerImageIterationBuildsImagesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataHcpPackerImageIterationBuildsImages | undefined;
    set internalValue(value: DataHcpPackerImageIterationBuildsImages | undefined);
    get createdAt(): string;
    get id(): string;
    get imageId(): string;
    get region(): string;
}
export declare class DataHcpPackerImageIterationBuildsImagesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataHcpPackerImageIterationBuildsImagesOutputReference;
}
export interface DataHcpPackerImageIterationBuilds {
}
export declare function dataHcpPackerImageIterationBuildsToTerraform(struct?: DataHcpPackerImageIterationBuilds): any;
export declare class DataHcpPackerImageIterationBuildsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataHcpPackerImageIterationBuilds | undefined;
    set internalValue(value: DataHcpPackerImageIterationBuilds | undefined);
    get cloudProvider(): string;
    get componentType(): string;
    get createdAt(): string;
    get id(): string;
    private _images;
    get images(): DataHcpPackerImageIterationBuildsImagesList;
    private _labels;
    get labels(): cdktf.StringMap;
    get packerRunUuid(): string;
    get status(): string;
    get updatedAt(): string;
}
export declare class DataHcpPackerImageIterationBuildsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataHcpPackerImageIterationBuildsOutputReference;
}
export interface DataHcpPackerImageIterationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration#default DataHcpPackerImageIteration#default}
    */
    readonly default?: string;
}
export declare function dataHcpPackerImageIterationTimeoutsToTerraform(struct?: DataHcpPackerImageIterationTimeoutsOutputReference | DataHcpPackerImageIterationTimeouts | cdktf.IResolvable): any;
export declare class DataHcpPackerImageIterationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpPackerImageIterationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataHcpPackerImageIterationTimeouts | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration hcp_packer_image_iteration}
*/
export declare class DataHcpPackerImageIteration extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_packer_image_iteration";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/hcp/d/packer_image_iteration hcp_packer_image_iteration} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpPackerImageIterationConfig
    */
    constructor(scope: Construct, id: string, config: DataHcpPackerImageIterationConfig);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    private _builds;
    get builds(): DataHcpPackerImageIterationBuildsList;
    private _channel?;
    get channel(): string;
    set channel(value: string);
    get channelInput(): string | undefined;
    get createdAt(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get incrementalVersion(): number;
    get organizationId(): string;
    get projectId(): string;
    get revokeAt(): string;
    private _timeouts;
    get timeouts(): DataHcpPackerImageIterationTimeoutsOutputReference;
    putTimeouts(value: DataHcpPackerImageIterationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataHcpPackerImageIterationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
