import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpPackerImageConfig extends cdktf.TerraformMetaArguments {
    /**
    * The slug of the HCP Packer Registry image bucket to pull from.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#bucket_name DataHcpPackerImage#bucket_name}
    */
    readonly bucketName: string;
    /**
    * The channel that points to the version of the image being retrieved. Either this or `iteration_id` must be specified. Note: will incur a billable request
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#channel DataHcpPackerImage#channel}
    */
    readonly channel?: string;
    /**
    * Name of the cloud provider this image is stored-in.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#cloud_provider DataHcpPackerImage#cloud_provider}
    */
    readonly cloudProvider: string;
    /**
    * Name of the builder that built this image. Ex: `amazon-ebs.example`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#component_type DataHcpPackerImage#component_type}
    */
    readonly componentType?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#id DataHcpPackerImage#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The iteration from which to get the image. Either this or `channel` must be specified.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#iteration_id DataHcpPackerImage#iteration_id}
    */
    readonly iterationId?: string;
    /**
    * Region this image is stored in, if any.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#region DataHcpPackerImage#region}
    */
    readonly region: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#timeouts DataHcpPackerImage#timeouts}
    */
    readonly timeouts?: DataHcpPackerImageTimeouts;
}
export interface DataHcpPackerImageTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/d/packer_image#default DataHcpPackerImage#default}
    */
    readonly default?: string;
}
export declare function dataHcpPackerImageTimeoutsToTerraform(struct?: DataHcpPackerImageTimeoutsOutputReference | DataHcpPackerImageTimeouts | cdktf.IResolvable): any;
export declare class DataHcpPackerImageTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpPackerImageTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataHcpPackerImageTimeouts | cdktf.IResolvable | undefined);
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/hcp/d/packer_image hcp_packer_image}
*/
export declare class DataHcpPackerImage extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_packer_image";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/hcp/d/packer_image hcp_packer_image} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpPackerImageConfig
    */
    constructor(scope: Construct, id: string, config: DataHcpPackerImageConfig);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    get buildId(): string;
    private _channel?;
    get channel(): string;
    set channel(value: string);
    resetChannel(): void;
    get channelInput(): string | undefined;
    get cloudImageId(): string;
    private _cloudProvider?;
    get cloudProvider(): string;
    set cloudProvider(value: string);
    get cloudProviderInput(): string | undefined;
    private _componentType?;
    get componentType(): string;
    set componentType(value: string);
    resetComponentType(): void;
    get componentTypeInput(): string | undefined;
    get createdAt(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _iterationId?;
    get iterationId(): string;
    set iterationId(value: string);
    resetIterationId(): void;
    get iterationIdInput(): string | undefined;
    private _labels;
    get labels(): cdktf.StringMap;
    get organizationId(): string;
    get packerRunUuid(): string;
    get projectId(): string;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    get revokeAt(): string;
    private _timeouts;
    get timeouts(): DataHcpPackerImageTimeoutsOutputReference;
    putTimeouts(value: DataHcpPackerImageTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataHcpPackerImageTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
