import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HvnPeeringConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique URL of one of the HVNs being peered.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#hvn_1 HvnPeeringConnection#hvn_1}
    */
    readonly hvn1: string;
    /**
    * The unique URL of one of the HVNs being peered.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#hvn_2 HvnPeeringConnection#hvn_2}
    */
    readonly hvn2: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#id HvnPeeringConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#timeouts HvnPeeringConnection#timeouts}
    */
    readonly timeouts?: HvnPeeringConnectionTimeouts;
}
export interface HvnPeeringConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#create HvnPeeringConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#default HvnPeeringConnection#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection#delete HvnPeeringConnection#delete}
    */
    readonly delete?: string;
}
export declare function hvnPeeringConnectionTimeoutsToTerraform(struct?: HvnPeeringConnectionTimeoutsOutputReference | HvnPeeringConnectionTimeouts | cdktf.IResolvable): any;
export declare class HvnPeeringConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HvnPeeringConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: HvnPeeringConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection hcp_hvn_peering_connection}
*/
export declare class HvnPeeringConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_hvn_peering_connection";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/hcp/r/hvn_peering_connection hcp_hvn_peering_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HvnPeeringConnectionConfig
    */
    constructor(scope: Construct, id: string, config: HvnPeeringConnectionConfig);
    get createdAt(): string;
    get expiresAt(): string;
    private _hvn1?;
    get hvn1(): string;
    set hvn1(value: string);
    get hvn1Input(): string | undefined;
    private _hvn2?;
    get hvn2(): string;
    set hvn2(value: string);
    get hvn2Input(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get organizationId(): string;
    get peeringId(): string;
    get projectId(): string;
    get selfLink(): string;
    get state(): string;
    private _timeouts;
    get timeouts(): HvnPeeringConnectionTimeoutsOutputReference;
    putTimeouts(value: HvnPeeringConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | HvnPeeringConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
