import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HvnRouteConfig extends cdktf.TerraformMetaArguments {
    /**
    * The destination CIDR of the HVN route.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#destination_cidr HvnRoute#destination_cidr}
    */
    readonly destinationCidr: string;
    /**
    * The `self_link` of the HashiCorp Virtual Network (HVN).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#hvn_link HvnRoute#hvn_link}
    */
    readonly hvnLink: string;
    /**
    * The ID of the HVN route.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#hvn_route_id HvnRoute#hvn_route_id}
    */
    readonly hvnRouteId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#id HvnRoute#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A unique URL identifying the target of the HVN route. Examples of the target: [`aws_network_peering`](aws_network_peering.md), [`aws_transit_gateway_attachment`](aws_transit_gateway_attachment.md)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#target_link HvnRoute#target_link}
    */
    readonly targetLink: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#timeouts HvnRoute#timeouts}
    */
    readonly timeouts?: HvnRouteTimeouts;
}
export interface HvnRouteTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#create HvnRoute#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#default HvnRoute#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route#delete HvnRoute#delete}
    */
    readonly delete?: string;
}
export declare function hvnRouteTimeoutsToTerraform(struct?: HvnRouteTimeoutsOutputReference | HvnRouteTimeouts | cdktf.IResolvable): any;
export declare class HvnRouteTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HvnRouteTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: HvnRouteTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route hcp_hvn_route}
*/
export declare class HvnRoute extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_hvn_route";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/hcp/r/hvn_route hcp_hvn_route} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HvnRouteConfig
    */
    constructor(scope: Construct, id: string, config: HvnRouteConfig);
    get createdAt(): string;
    private _destinationCidr?;
    get destinationCidr(): string;
    set destinationCidr(value: string);
    get destinationCidrInput(): string | undefined;
    private _hvnLink?;
    get hvnLink(): string;
    set hvnLink(value: string);
    get hvnLinkInput(): string | undefined;
    private _hvnRouteId?;
    get hvnRouteId(): string;
    set hvnRouteId(value: string);
    get hvnRouteIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get selfLink(): string;
    get state(): string;
    private _targetLink?;
    get targetLink(): string;
    set targetLink(value: string);
    get targetLinkInput(): string | undefined;
    private _timeouts;
    get timeouts(): HvnRouteTimeoutsOutputReference;
    putTimeouts(value: HvnRouteTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | HvnRouteTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
